import ftcomputing.robo.*;
/**
 * Erprobung einzelner Sensoren und Aktoren am ROBO TX Controller (COM4)
 * Testaufbau :
 * Motor M3 mit Endtaster I5 und Impulstaster I6 (setMotor,   Mot)
 * Motor M4 mit Endtaster I7 und Impulstaster I8
 * Taster an I1                                   (getInput,    Inp)
 * Distanzsensor an D1                            (getDistance, Inp)
 * Photowiderstand an AX                          (getAnalog,   Inp)
 * NTC                                            (getAnalog,   Inp)
 * Phototransistor an I4                          (getInput,    Inp)
 * Taster an I1                                   (getInput,    Inp)
 * Lampen an O1, O2, O3, O4                       (setLamp,     Out)
 * 
 * @author Ulrich Mller
 * @version 01.01.10
 */
public class Elemente {
    private FishFace ft;
    public Elemente(){
        ft = new FishFace();
        ft.openInterface(0, 0);
    }

    /**
     * Schalten der Aktoren an M1 - M4 bzw. O1 - O8
     * Motoren werden hier "einpolig" betrieben
     */
    public void outTest() {
        System.out.println("outTest gestartet");
        for(int i = 1; i <= 8; i++) {
            System.out.println("Out." + i);
            ft.setLamp(i, Dir.On);
            ft.waitForHigh(Inp.I1);
            ft.setLamp(i, Dir.Off);
        } 
        System.out.println("--- Finito ---");
    }
    
    /**
     * DistanzSensor an D1
     * Neuer Wert : Taster an I1
     */
    public void distSensor(int d) {
        System.out.println("DistanzSensor an : " + d);
        do {
            System.out.println("Entfernung [cm] : " + ft.getDistance(d));
            ft.waitForHigh(Inp.I1);
        } while(!ft.finish());
        System.out.println("--- Finito ---");
    }

    /**
     * Sensoren : NTC(1), Phototransistor(2), -widerstand(3)
     * Auswahl bei Start der Methode, neuer Wert : Taster an I1
     */
    public void sensoren(int i) {
        do {
            switch(i) {
                case 1:
                    System.out.println("NTC : " + ft.getAnalog(Inp.AY));
                    break;
                case 2:
                    System.out.println("Phototransistor : " + ft.getInput(Inp.I4));
                    break;
                case 3:
                    System.out.println("Photowiderstand : " + ft.getAnalog(Inp.AX));
                    break;
                default:
            }
            ft.waitForHigh(Inp.I1);
        } while(!ft.finish());
        System.out.println("--- Finito ---");
    }
    
    /**
     * Photowiderstand : berwachung Wertebereich
     */
    public void hellOK(int low, int high) {
        int wert;
        System.out.println("berwachung gestartet : " + low + " - " + high);
        do {
            wert = ft.getAnalog(Inp.AX);
            if (wert < low) System.out.println("Messwert zu niedrig : " + wert);
            else if(wert > high) System.out.println("Messwert zu hoch   : " + wert);
            else System.out.println("Messwert im zulssigen Bereich : " + wert);
            ft.pause(1234);
        } while(!ft.finish());
        System.out.println("--- See you later ---");
    }
    
    /**
     * Motor an M3 links bis I5, rechts bis I6
     */
    public void motPendel() {
        System.out.println("Motor M3 links bis I5 und rechts bis I6");
        do{
            ft.setMotor(Mot.M3, Dir.Left);
            ft.waitForInput(Inp.I5, true);
            ft.setMotor(Mot.M3, Dir.Off);
            ft.pause(1234);
            ft.setMotor(Mot.M3, Dir.Right);
            ft.waitForInput(Inp.I6, true);
            ft.setMotor(Mot.M3, Dir.Off);
            ft.pause(1234);            
        } while(!ft.finish());
        System.out.println("--- Finito ---");
    }
    
    /**
     * Motor an M1 wird fr die angegebenen Zeit betrieben
     */
    public void motorTime(int mSek) {
        System.out.println("Motor gestartet");
        ft.setMotor(Mot.M3, Dir.Left);
        ft.pause(mSek);
        ft.setMotor(Mot.M3, Dir.Off);
        System.out.println("Finito nach " + mSek + " Millisekunden");
   }
   
   /**
    * Motor an M3 und Impulstaster an I6 luft fr die angegeben Impulszahl
    */
   public void motorCount(int iCount) {
        System.out.println("Motor gestartet");
        ft.setMotor(Mot.M3, Dir.Left, Speed.Full, iCount);       
        ft.waitForMotors(Mot.M3);
        System.out.println("--- Finito ---");
    }
    
    /**
     * Motor an M3 luft links bis Endtaster an I5
     */
    public void goHome() {
        System.out.println("Motor Home, wartet auf I5");
        ft.setMotor(Mot.M3, Dir.Left);
        ft.waitForInput(Inp.I5);
        ft.setMotor(Mot.M3, Dir.Off);
        System.out.println("--- Zu Hause ---");
    }
    /**
     * Motoren an M3 und M4 mit I5/I7 als End- und I6/I8 als Impulstaster
     * fahren zunchst auf Home-Position (I5 && I7 true)
     * und dann die angegebene Impulszahl in die Gegenrichtung
     */
   public void motorRob(int iCount3, int iCount4) {
        System.out.println("Motor Home, wartet auf I5 und I7");
        ft.setMotor(Mot.M3, Dir.Left, Speed.Half, 9999);
        ft.setMotor(Mot.M4, Dir.Left, Speed.Full, 9999);
        ft.waitForMotors(0, Mot.M3, Mot.M4);
        System.out.println("Motor M3 to : " + iCount3);
        System.out.println("Motor M4 to : " + iCount4);
        ft.pause(1234);
        ft.setMotor(Mot.M3, Dir.Right, Speed.Full, iCount3);
        ft.setMotor(Mot.M4, Dir.Right, Speed.Half, iCount4);
        ft.waitForMotors(0, Mot.M3, Mot.M4);
        System.out.println("--- Finito ---");
    }
}
