import ftcomputing.robo.*;
/**
 * Einfhrung in die Programmierung der Industry Robot 
 * mit ftcomputing.robo.jar : FishFace
 * 
 * Sulenrobot nach Industry Robot II mit der dort angegebenen Interface-Belegung
 * Sule M1, Endtaster I1, Impulstaster I2, 
 * Arm waagerecht M2, I3, I4, Arm senkrecht M3, I5, I6
 * Greifer M4, I7, I8, alternative Lampe
 * Die Robotkomponenten mssen bei Linkslauf auf den zugehrenden Endtaster drehen.
 * 
 * @author Ulrich Mller 
 * @version 15.03.10
 */
public class RobTutZwei {
    private FishFace ft;
    private int[] actPos = new int[4];

    public RobTutZwei() {
        ft = new FishFace();
    }

    public void start() {
        ft.openInterface(0, 0);
    }
    public void ende() {
        ft.closeInterface();
    }
    /**
     * Fahren auf Home-Position
     */
    public void driveHome(int motNr) {
        int endT = motNr*2-1;
        System.out.println("Motor M" + motNr + " -> Home, wartet auf I" + endT);
        ft.setMotor(motNr, Dir.Left);
        ft.waitForInput(endT);
        ft.setMotor(motNr, Dir.Off);
        actPos[motNr-1] = 0;
        System.out.println("M" + motNr + "--- Zu Hause ---");
    }
    
    /**
     * Simultanes Anfahren der Home-Position des ganzen Roboters
     */
    public void moveHome() {
        System.out.println("Es geht nach Hause");
        for(int i = 1; i <= 3; i++) ft.setMotor(i, Dir.Left, Speed.Full, 9999);
        ft.waitForMotors(0, Mot.M1, Mot.M2, Mot.M3);
        for(int i = 0; i < 3; i++) actPos[i] = 0;
        System.out.println("--- wir sind zu Hause ---");
    }
    
    /**
     * Fahren auf vorgegebene Position
     */
    public void driveTo(int motNr, int pos) {
        System.out.println("Motor M" + motNr + " fhrt auf Position : " + pos);
        if (pos < actPos[motNr-1]) ft.setMotor(motNr, Dir.Left, Speed.Full, 
          actPos[motNr-1] - pos);
        else if (pos > actPos[motNr-1]) ft.setMotor(motNr, Dir.Right, Speed.Full, 
          pos - actPos[motNr-1]);
        while(ft.waitForMotors(1111, motNr) == Wait.Time)
            System.out.print(" - " + ft.getCounter(motNr*2));
        System.out.println();
        actPos[motNr-1] = pos;
        System.out.println("Auf Position : " + pos);
    }
    
    /**
     * Simultanes Anfahren einer vorgegebenen Position
     */
    public void moveTo(int... pos) {
       System.out.println("Robot fhrt auf neue Position");
       for(int i = 0; i < pos.length; i++) {
           if(pos[i] < actPos[i]) ft.setMotor(i+1, Dir.Left, Speed.Full,
             actPos[i] - pos[i]);
           else if(pos[i] > actPos[i]) ft.setMotor(i+1, Dir.Right, Speed.Full,
             pos[i] - actPos[i]);
        }
        ft.waitForMotors(0, 1, 2, 3);
        for(int j = 0; j < pos.length; j++) actPos[j] = pos[j];
        System.out.println("--- Mir san doa ---");
    }
}
